@@ -28,7 +28,7 @@ import sys
 # When you're working on a test and need to see logging - both from the test
 # code and the code _under_ test - uncomment the following line.
 #
-# logging.basicConfig(level=logging.INFO)
+# logging.basicConfig(level=logging.DEBUG)
 
 _log = logging.getLogger(__name__)
 
@@ -56,6 +56,7 @@ sys.modules['networking_calico.compat'] = m_compat = mock.MagicMock()
 port1 = {'binding:vif_type': 'tap',
          'binding:host_id': 'felix-host-1',
          'id': 'DEADBEEF-1234-5678',
+         'network_id': 'calico-network-id',
          'device_id': 'instance-1',
          'device_owner': 'compute:nova',
          'fixed_ips': [{'subnet_id': 'subnet-id-10.65.0--24',
@@ -68,6 +69,7 @@ port1 = {'binding:vif_type': 'tap',
 port2 = {'binding:vif_type': 'tap',
          'binding:host_id': 'felix-host-1',
          'id': 'FACEBEEF-1234-5678',
+         'network_id': 'calico-network-id',
          'device_id': 'instance-2',
          'device_owner': 'compute:nova',
          'fixed_ips': [{'subnet_id': 'subnet-id-10.65.0--24',
@@ -81,6 +83,7 @@ port2 = {'binding:vif_type': 'tap',
 port3 = {'binding:vif_type': 'tap',
          'binding:host_id': 'felix-host-2',
          'id': 'HELLO-1234-5678',
+         'network_id': 'calico-network-id',
          'device_id': 'instance-3',
          'device_owner': 'compute:nova',
          'fixed_ips': [{'subnet_id': 'subnet-id-2001:db8:a41:2--64',
@@ -166,11 +169,20 @@ class GrandDukeOfSalzburg(object):
 m_neutron.plugins.ml2.drivers.mech_agent.SimpleAgentMechanismDriverBase = \
     DriverBase
 
-# Replace the elector.
+# Import all modules used by the mechanism driver so we can hook their logging.
+from networking_calico import datamodel_v3
+from networking_calico import etcdutils
+from networking_calico import etcdv3
+from networking_calico.plugins.ml2.drivers.calico import election
+from networking_calico.plugins.ml2.drivers.calico import endpoints
+from networking_calico.plugins.ml2.drivers.calico import mech_calico
+from networking_calico.plugins.ml2.drivers.calico import policy
+from networking_calico.plugins.ml2.drivers.calico import status
+from networking_calico.plugins.ml2.drivers.calico import subnets
+from networking_calico.plugins.ml2.drivers.calico import syncer
 
-import networking_calico.plugins.ml2.drivers.calico.mech_calico as mech_calico
-import networking_calico.plugins.ml2.drivers.calico.t_etcd as t_etcd
-t_etcd.Elector = GrandDukeOfSalzburg
+# Replace the elector.
+mech_calico.Elector = GrandDukeOfSalzburg
 
 REAL_EVENTLET_SLEEP_TIME = 0.01
 
@@ -361,6 +373,7 @@ class Lib(object):
 
             # Remember this thread.
             self.threads.append(thread)
+            _log.info("New thread %s", thread)
 
             # Also return it.
             return thread
@@ -384,14 +397,26 @@ class Lib(object):
         eventlet.spawn_after = simulated_spawn_after
 
     def setUp_logging(self):
-        """Setup to intercept and display logging by the code under test."""
+        """Setup to intercept and display logging by the code under test.
+
+        To see this logging, you also need to uncomment the logging.basicConfig
+        call near the top of this file.
+        """
         import logging
-        mech_calico.LOG = logging.getLogger(
-            'networking_calico.plugins.ml2.drivers.calico.mech_calico'
-        )
-        t_etcd.LOG = logging.getLogger(
-            'networking_calico.plugins.ml2.drivers.calico.t_etcd'
-        )
+        for module in [
+                election,
+                endpoints,
+                mech_calico,
+                policy,
+                status,
+                subnets,
+                syncer,
+                datamodel_v3,
+                etcdutils,
+                etcdv3,
+        ]:
+            module.LOG = logging.getLogger("\t%-15s\t" %
+                                           module.__name__.split('.')[-1])
 
     # Tear down after each test case.
     def tearDown(self):
@@ -399,7 +424,9 @@ class Lib(object):
         _log.info("Clean up remaining green threads...")
 
         for thread in self.threads:
+            _log.info("Kill thread %s", thread)
             thread.kill()
+        _log.info("All threads killed")
 
         # Stop hooking eventlet.
         self.tearDown_eventlet()
@@ -555,6 +582,7 @@ class FixedUUID(object):
     def __enter__(self):
         guid = mock.MagicMock()
         guid.get_hex.return_value = self.uuid
+        guid.__str__.return_value = self.uuid
         uuid4 = self.uuid4_p.start()
         uuid4.return_value = guid
 
